import {
  select,
  csv ,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  format,
  scaleOrdinal,
  schemeCategory
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const title = 'Penguin Dataset';
  
  const xValue = d => d.flipper_length_mm;
  const xAxisLabel = 'Flipper Length (mm)';
  
  const yValue = d => d.body_mass_g;
  const circleRadius = 5;
  const yAxisLabel = 'Body Mass (g)';
  
  const colorValue = d => d.species;
  const colorScale = scaleOrdinal()
  .domain(['species A', 'species B', 'species C'])
  .range(['red', 'blue', 'orange']);
  
  const margin = { top: 60, right: 40, bottom: 88, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -93)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 75)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  g.selectAll('square').data(data)
    .enter().append('square')
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius)
      .attr('fill', d => colorScale(colorValue(d)));
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};

csv ('https://gist.githubusercontent.com/saisreearibandi/622f29a36bc20a7cfd3b1b1464307ea0/raw/c1ec753ef38ac7473182832c169c729225ebb5fb/Penguins.csv')
  .then(data => {
    data.forEach(d => {
    
      d.bill_length_mm = +d.bill_length_mm;
      d.bill_depth_mm = +d.bill_depth_mm;
      d.flipper_length_mm = +d.flipper_length_mm;
      d.body_mass_g = +d.body_mass_g;  
    });
    render(data);
  });